Plotting (API) — FAN-C 0.9.1-beta documentation

# Plotting (API)

All plot types produced with the `fancplot` executable in Basic usage are also available in the Python API. These plots are based on Matplotlib, the Python plotting API, and therefore highly customisable.

Note

To follow along yourself with the examples in this section, please complete the command line tutorial first, so that all the necessary files have been generated in the output folder.

- Plotting basics
  - BasePlotter
  - Using dedicated Matplotlib Axes
- Matrix plots
  - Square matrix
  - Triangular matrix
  - Split matrix
  - Mirrored plot
- Region and score plots
  - Line plot
  - Bar plot
  - Score heatmaps
  - Layer plots
  - Gene plots